var get = require('lodash.get');
var dateFns = require('date-fns');
var jsonSchemaToYup = require('json-schema-to-yup');
var isArray = require('lodash.isarray');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var get__default = /*#__PURE__*/_interopDefaultLegacy(get);
var isArray__default = /*#__PURE__*/_interopDefaultLegacy(isArray);

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}
function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
  return arr2;
}
function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);
  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

// Desc: Configs for the translation that is used in the validation messages
var translatesConfig = {
  nullable: 'generic-form:validation.nullable',
  required: 'generic-form:validation.required',
  min: 'generic-form:validation.min',
  max: 'generic-form:validation.max',
  maxLength: 'generic-form:validation.max_length',
  minLength: 'generic-form:validation.min_length',
  pattern: 'generic-form:validation.pattern',
  format: 'generic-form:validation.format',
  email: 'generic-form:validation.email',
  minDate: 'generic-form:validation.min_date',
  maxDate: 'generic-form:validation.max_date',
  wrongRange: 'generic-form:validation.wrong_range',
  wrongDate: 'generic-form:validation.wrong_range',
  trim: 'generic-form:validation.trim',
  oneOf: 'generic-form:validation.one_of'
};
// Desc: Enum for the validation error types
var EValidationTypes;
(function (EValidationTypes) {
  EValidationTypes["nullable"] = "nullable";
  EValidationTypes["required"] = "required";
  EValidationTypes["min"] = "min";
  EValidationTypes["max"] = "max";
  EValidationTypes["oneOf"] = "oneOf";
  EValidationTypes["maxLength"] = "maxLength";
  EValidationTypes["minLength"] = "minLength";
  EValidationTypes["pattern"] = "pattern";
  EValidationTypes["format"] = "format";
  EValidationTypes["minDate"] = "minDate";
  EValidationTypes["maxDate"] = "maxDate";
  EValidationTypes["wrongRange"] = "wrongRange";
  EValidationTypes["wrongDate"] = "wrongDate";
  EValidationTypes["trim"] = "trim";
})(EValidationTypes || (EValidationTypes = {}));

exports.EFieldTypes = void 0;
(function (EFieldTypes) {
  EFieldTypes["TEXT"] = "text";
  EFieldTypes["NUMBER"] = "number";
  EFieldTypes["SWITCH"] = "switch";
  EFieldTypes["DATE"] = "date";
  EFieldTypes["DATE_RANGE"] = "dateRange";
  EFieldTypes["AUTOCOMPLETE"] = "autoComplete";
  EFieldTypes["FILE"] = "file";
  EFieldTypes["ARRAY"] = "array";
  EFieldTypes["MOBILE_PHONE"] = "mobilePhone";
  EFieldTypes["MULTIPLE_AUTOCOMPLETE"] = "autoCompleteMultiple";
  EFieldTypes["RADIOBUTTON"] = "radioButton";
  EFieldTypes["EMPTY"] = "empty";
  EFieldTypes["CHECKBOX"] = "checkbox";
  EFieldTypes["RADIOBUTTON_MATRIX"] = "radioButtonMatrix";
  EFieldTypes["RATING"] = "rating";
})(exports.EFieldTypes || (exports.EFieldTypes = {}));

/**
 * @param formDataChildren - array of form fields
 * @param acc - accumulator, used for recursion
 * @returns {[key: string]: any} - object with the initial values for the form
 * @description getInitialValues function returns an object with the initial values for the form
 * based on the initial values provided in the json schema
 */

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
} /**
   * @param schema - yup schema
   * @param fieldName - field name to get the rule value from
   * @param ruleName - rule name to get the value from
   * @returns {any} - rule value
   * @description getRuleValueFromSchema function returns the value of a rule from a yup schema
   * based on the field name and rule name. This value is needed for passing meta to translations.
   * @example getRuleValueFromSchema(schema, 'email', 'minLength') => 6
   */
var getInitialValues = function getInitialValues(formDataChildren, acc) {
  if (acc === void 0) {
    acc = {};
  }
  return formDataChildren.reduce(function (acc, item) {
    if (isFormGroup(item)) {
      return getInitialValues(item.children, acc);
    }
    acc[item.fieldName] = item.initialValue === null ? undefined : item.initialValue;
    return acc;
  }, acc);
};
var getRuleValueFromSchema = function getRuleValueFromSchema(schema, fieldName, ruleName) {
  var describedSchema = schema.describe();
  var rules = get__default["default"](describedSchema, "fields." + fieldName + ".tests", []);
  var rule = rules.find(function (rule) {
    return rule.name === ruleName;
  });
  return get__default["default"](rule, "params." + ruleName, undefined);
};
/**
 * @param type - validation type
 * @param value - value to be validated
 * @param t - translation function(optional)
 * @param validationParam - validation param(meta) to be passed to the translation function(optional) or error object
 * @returns {any} - error object or function, or translated string
 * @description getFieldError function returns an error object or function, or translated string based on the validation type
 */
var getFieldError = function getFieldError(type, value, t, validationParam) {
  var translationKey = get__default["default"](translatesConfig, "" + type);
  switch (type) {
    case EValidationTypes.nullable:
      return t ? t(translationKey) : createErrorObject(translationKey);
    case EValidationTypes.required:
      return t ? t(translationKey) : createErrorObject(translationKey);
    case EValidationTypes.min:
      return t ? function (_ref) {
        var min = _ref.min;
        return t(translationKey, {
          param: min
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.max:
      return t ? function (_ref2) {
        var max = _ref2.max;
        return t(translationKey, {
          param: max
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.maxLength:
      return t ? function (_ref3) {
        var maxLength = _ref3.maxLength;
        return t(translationKey, {
          param: maxLength
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.minLength:
      return t ? function (_ref4) {
        var minLength = _ref4.minLength;
        return t(translationKey, {
          param: minLength
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.format:
      if (value) {
        translationKey = get__default["default"](translatesConfig, "" + type) ? get__default["default"](translatesConfig, "" + type) : translationKey;
      }
      return t ? t(translationKey) : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.trim:
    case EValidationTypes.oneOf:
    case EValidationTypes.pattern:
      return t ? t(translationKey) : createErrorObject(translationKey, {
        param: validationParam
      });
    default:
      return null;
  }
};
/**
 * @param validationObject
 * @param formValues - form values to be validated
 * @returns {IValidationErrors} - object with the validation errors
 * @description makeCrossFieldValidation function makes custom cross-field validation
 * and returns an object with the validation errors
 */
var makeCrossFieldValidation = function makeCrossFieldValidation(validationObject, formValues) {
  var errors = {};
  try {
    var keys = Object.keys(validationObject);
    keys.forEach(function (fieldName) {
      var rules = validationObject[fieldName];
      var fieldErrors = {
        property: fieldName,
        constraints: {}
      };
      rules == null || rules.forEach(function (rule, id) {
        var errorKey = rule.errorKey,
          testCondition = rule.testCondition,
          meta = rule.meta;
        var testFunction = functionFromString(testCondition);
        var shouldIncludeError = false;
        try {
          shouldIncludeError = testFunction(formValues);
        } catch (e) {
          console.log('Error during evaluating custom validation rule. This issue wont cause an error, current validation was skipped', e);
        }
        if (shouldIncludeError) {
          fieldErrors.constraints[id] = createErrorObject(errorKey, meta);
        }
      });
      if (Object.keys(fieldErrors.constraints).length > 0) {
        errors[fieldName] = fieldErrors;
      }
    });
    return errors;
  } catch (e) {
    console.warn('Error in makeCrossFieldValidation: ', e);
    return {};
  }
};
/**
 * @param fieldName - field name
 * @param values - form values
 * @param errors - object with the validation errors
 * @returns {IValidationErrors} - object with the validation errors
 * @description validateDateRangeField function validates date range field
 * and returns an object with the validation errors
 */
var validateDateRangeField = function validateDateRangeField(fieldName, values, errors) {
  if (errors === void 0) {
    errors = {};
  }
  var minDate = dateFns.subYears(new Date(), 100);
  var maxDate = dateFns.addYears(new Date(), 100);
  var error = {
    property: fieldName,
    constraints: {}
  };
  var dateRangeUnmapped = get__default["default"](values, fieldName, [null, null]);
  if (!isArray__default["default"](dateRangeUnmapped)) {
    error.constraints[EValidationTypes.wrongDate] = {
      translationKey: translatesConfig[EValidationTypes.wrongDate],
      fallbackLanguageTranslation: 'This field expected to be array of strings',
      meta: {}
    };
    if (!errors[fieldName]) {
      errors[fieldName] = error;
    } else {
      errors[fieldName].constraints = _extends({}, errors[fieldName].constraints, error.constraints);
    }
    return errors;
  }
  var dateRange = dateRangeUnmapped.map(function (value) {
    return value ? dateFns.parse(value, 'yyyy-MM-dd', new Date()) : null;
  });
  if (!dateFns.isValid(dateRange[0]) || !dateFns.isValid(dateRange[1])) {
    error.constraints[EValidationTypes.wrongDate] = {
      translationKey: translatesConfig[EValidationTypes.wrongDate],
      fallbackLanguageTranslation: 'Some date in range is invalid',
      meta: {}
    };
  }
  if (!dateRange[0] || !dateRange[1]) {
    error.constraints[EValidationTypes.required] = {
      translationKey: translatesConfig[EValidationTypes.required],
      fallbackLanguageTranslation: 'Some date in range is empty',
      meta: {}
    };
  }
  if (dateRange[0] && dateFns.isBefore(dateRange[0], minDate) || dateRange[1] && dateFns.isBefore(dateRange[1], minDate)) {
    error.constraints[EValidationTypes.minDate] = {
      translationKey: translatesConfig[EValidationTypes.minDate],
      fallbackLanguageTranslation: 'Date range should be between 100 years ago and 100 years in the future',
      meta: {}
    };
  }
  if (dateRange[1] && dateFns.isAfter(dateRange[1], maxDate) || dateRange[0] && dateFns.isAfter(dateRange[0], maxDate)) {
    error.constraints[EValidationTypes.maxDate] = {
      translationKey: translatesConfig[EValidationTypes.maxDate],
      fallbackLanguageTranslation: 'Date range should be between 100 years ago and 100 years in the future',
      meta: {}
    };
  }
  if (dateRange[0] && dateRange[1] && (dateFns.isAfter(dateRange[0], dateRange[1]) || dateFns.isEqual(dateRange[0], dateRange[1]))) {
    error.constraints[EValidationTypes.wrongRange] = {
      translationKey: translatesConfig[EValidationTypes.wrongRange],
      fallbackLanguageTranslation: 'Start date should be before end date',
      meta: {}
    };
  }
  if (Object.keys(error.constraints).length > 0) {
    if (!errors[fieldName]) {
      errors[fieldName] = error;
    } else {
      errors[fieldName].constraints = _extends({}, errors[fieldName].constraints, error.constraints);
    }
  }
  return errors;
};
/**
 * @param jsonSchema - json validation schema
 * @param t - translation function(optional)
 * @returns {AnyObjectSchema} - yup validation schema
 * @description buildYupSchema function builds a yup validation schema based on the json validation schema
 */
var buildYupSchema = function buildYupSchema(jsonSchema, t) {
  return jsonSchemaToYup.buildYup(jsonSchema, t ? {
    errMessages: getErrorMessages(jsonSchema, t)
  } : undefined);
};
/**
 * @param form {IForm} - form json schema
 * @param valuesToValidate {any} - form values to be validated
 * @param skipCrossField {boolean} - skip cross-field validation(optional)
 * @returns {Promise<unknown>} - object with the validation errors or error that has occurred during the validation
 * @description validateValues function validates the form values based on the json form object
 */
var validateValues = function validateValues(_ref5, valuesToValidate, skipCrossField) {
  var children = _ref5.children,
    jsonSchema = _ref5.jsonSchema,
    formSettings = _ref5.formSettings;
  if (skipCrossField === void 0) {
    skipCrossField = false;
  }
  try {
    var _temp2 = function _temp2(_result) {
      return _exit ? _result : {
        errors: Object.values(errors)
      };
    };
    var _exit;
    var errors = {};
    var flattenedValues = flattenValues(valuesToValidate);
    var trimmedValues = trimValuesInObject(flattenedValues);
    var _temp = _catch(function () {
      var validationSchema = buildYupSchema(jsonSchema);
      var dateRangeFields = getFieldNamesByType(children, exports.EFieldTypes.DATE_RANGE);
      if (!skipCrossField) {
        var formFieldNames = Object.keys(formSettings);
        var crossFieldValidations = formFieldNames.reduce(function (acc, el) {
          if (!formSettings[el].crossFieldValidations) {
            return acc;
          }
          acc[el] = formSettings[el].crossFieldValidations;
          return acc;
        }, {});
        errors = makeCrossFieldValidation(crossFieldValidations, trimmedValues);
      }
      if (dateRangeFields.length > 0) {
        dateRangeFields.forEach(function (fieldName) {
          errors = validateDateRangeField(fieldName, trimmedValues, errors);
        });
      }
      return Promise.resolve(validationSchema.validate(trimmedValues, {
        abortEarly: false
      })).then(function () {});
    }, function (e) {
      if (get__default["default"](e, 'name') === 'ValidationError') {
        errors = formatYupValidationErrors(e, errors);
      } else {
        throw e;
      }
    });
    return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
  } catch (e) {
    return Promise.reject(e);
  }
};

var _excluded = ["grid", "renderCondition", "disabledCondition"],
  _excluded2 = ["crossFieldValidations"];
var buildOptionsFromChildren = function buildOptionsFromChildren(children, formOptions) {
  if (formOptions === void 0) {
    formOptions = {};
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return buildOptionsFromChildren(child.children, acc);
    }
    var fieldLayout = child.grid || {
      md: 12,
      sm: 12,
      xs: 12
    };
    acc[child.fieldName] = {
      crossFieldConditions: {
        renderCondition: child.renderCondition,
        disabledCondition: child.disabledCondition
      },
      fieldLayout: fieldLayout
    };
    return acc;
  }, formOptions);
};
var sanitizeChildrenFunction = function sanitizeChildrenFunction(children) {
  return children.map(function (child) {
    if (isFormGroup(child)) {
      return _extends({}, child, {
        children: sanitizeChildrenFunction(child.children)
      });
    }
    var sanitizedChild = _objectWithoutPropertiesLoose(child, _excluded);
    return sanitizedChild;
  });
};
var parseFormV1 = function parseFormV1(form) {
  var submitButtonText = form.submitButtonText,
    cancelButtonText = form.cancelButtonText,
    _form$validationObjec = form.validationObject,
    crossFieldValidations = _form$validationObjec.crossFieldValidations,
    sanitizedValidationObject = _objectWithoutPropertiesLoose(_form$validationObjec, _excluded2),
    children = form.children;
  var formOptions = buildOptionsFromChildren(children);
  var fieldsWithCrossFieldValidations = Object.keys(crossFieldValidations);
  fieldsWithCrossFieldValidations.forEach(function (key) {
    formOptions[key].crossFieldValidations = crossFieldValidations[key];
  });
  var sanitizedChildren = sanitizeChildrenFunction(children);
  return {
    formatVersion: 'parsed',
    jsonSchema: sanitizedValidationObject,
    formSettings: formOptions,
    children: sanitizedChildren,
    submitButtonText: submitButtonText,
    cancelButtonText: cancelButtonText
  };
};

var parseFormV2 = function parseFormV2(form) {
  var submitButtonText = form.submitButtonText,
    cancelButtonText = form.cancelButtonText,
    validationObject = form.validationObject,
    crossFieldValidations = form.crossFieldValidations,
    crossFieldConditions = form.crossFieldConditions,
    formLayout = form.formLayout,
    children = form.children;
  var allFieldNames = Object.keys(validationObject.properties);
  var formOptions = allFieldNames.reduce(function (acc, fieldName) {
    var fieldLayout = formLayout[fieldName] || {
      md: 12,
      sm: 12,
      xs: 12
    };
    acc[fieldName] = {
      crossFieldValidations: crossFieldValidations == null ? void 0 : crossFieldValidations[fieldName],
      crossFieldConditions: crossFieldConditions == null ? void 0 : crossFieldConditions[fieldName],
      fieldLayout: fieldLayout
    };
    return acc;
  }, {});
  return {
    formatVersion: 'parsed',
    jsonSchema: validationObject,
    formSettings: formOptions,
    children: children,
    submitButtonText: submitButtonText,
    cancelButtonText: cancelButtonText
  };
};

/**
 * @param jsonSchema - jsonSchema validation object
 * @param t - i18n translate function
 * @returns {any}
 * @description getErrorMessages function returns an object with the error messages for each field in the form based on the jsonSchema
 */
var getErrorMessages = function getErrorMessages(jsonSchema, t) {
  var errMessages = {};
  Object.keys(jsonSchema.properties).forEach(function (property) {
    errMessages[property] = {};
    Object.keys(jsonSchema.properties[property]).forEach(function (key) {
      var value = jsonSchema.properties[property][key];
      errMessages[property][key] = getFieldError(key, value, t);
      if (Object.keys(jsonSchema).includes(key)) {
        errMessages[property].required = getFieldError('required', null, t);
      }
    });
  });
  return errMessages;
};
/**
 * @param translateKey
 * @param param
 * @returns {IValidationError}
 * @description createErrorObject function returns an object with the error message
 * for a field in the form in a proper format
 * @example createErrorObject('required', { param: 'email' }) => { translationKey: 'required', fallbackLanguageTranslation: 'This field is required', meta: { param: 'email' } }
 */
var createErrorObject = function createErrorObject(translateKey, param) {
  return {
    translationKey: translateKey,
    fallbackLanguageTranslation: translateKey,
    meta: param || {}
  };
};
function isFormGroup(toBeDetermined) {
  return !!toBeDetermined.children;
}
/**
 * @param stringifiedFunction
 * @returns {Function}
 * @description functionFromString returns a function from a stringified function
 * @example functionFromString('/Function((values) => {return values.medicalConditions.toString() === 'true'})/')
 * => (values) => values.medicalConditions.toString() === 'true'
 */
var functionFromString = function functionFromString(stringifiedFunction) {
  try {
    var substr = stringifiedFunction.substring(10, stringifiedFunction.length - 2);
    return (0, eval)('(' + substr + ')');
  } catch (e) {
    console.log('Error parsing custom validation function in functionFromString. This issue wont cause an error, current validation was skipped', e);
    return function () {
      return false;
    };
  }
};
/**
 * @param validationError - yup validation error
 * @param initialErrors - initial errors object to be merged with the yup validation errors
 * @returns {IValidationErrors} - returns an object with the errors for each field in the form
 * @description formatYupValidationErrors function returns an object with the errors for each field in the form
 * based on the yup validation error formatting to be used in the GenericForm component
 * @example formatYupValidationErrors(yupValidationError, { email: { property: 'email', constraints: { required: { translationKey: 'required', fallbackLanguageTranslation: 'This field is required', meta: {} } } } })
 */
var formatYupValidationErrors = function formatYupValidationErrors(validationError, initialErrors) {
  if (initialErrors === void 0) {
    initialErrors = {};
  }
  var errors = _extends({}, initialErrors);
  for (var _iterator = _createForOfIteratorHelperLoose(validationError.inner), _step; !(_step = _iterator()).done;) {
    var _propertyValidationEr;
    var propertyValidationError = _step.value;
    var errorType = propertyValidationError.type;
    if (!errorType && (_propertyValidationEr = propertyValidationError.params) != null && _propertyValidationEr.regex) {
      var _propertyValidationEr2;
      if (!((_propertyValidationEr2 = propertyValidationError.params) != null && _propertyValidationEr2.regex)) {
        continue;
      }
      errorType = 'pattern';
    }
    if (!get__default["default"](errors, "" + propertyValidationError.path)) {
      errors[propertyValidationError.path] = {
        property: propertyValidationError.path,
        constraints: {}
      };
    }
    errors[propertyValidationError.path].constraints[errorType] = _extends({}, getFieldError(errorType, get__default["default"](propertyValidationError, 'path', null), undefined, get__default["default"](propertyValidationError.params, "" + propertyValidationError.type)), {
      fallbackLanguageTranslation: propertyValidationError.message
    });
  }
  return errors;
};
/**
 * @param children
 * @param type - field type
 * @param acc - accumulator, used for recursion
 * @returns {string[]} - array of field names
 * @description getFieldNamesByType function returns an array of field names based on the field type
 * @example getFieldNamesByType(form, EFieldTypes.TEXT) => ['firstName', 'lastName']
 */
var getFieldNamesByType = function getFieldNamesByType(children, type, acc) {
  if (acc === void 0) {
    acc = [];
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return getFieldNamesByType(child.children, type, acc);
    }
    if (child.type === type) {
      acc.push(child.fieldName);
    }
    return acc;
  }, acc);
};
var getAllFieldNames = function getAllFieldNames(children, acc) {
  if (acc === void 0) {
    acc = [];
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return getAllFieldNames(child.children, acc);
    }
    acc.push(child.fieldName);
    return acc;
  }, acc);
};
var flattenValues = function flattenValues(obj) {
  var flattenedValues = _extends({}, obj);
  var keys = Object.keys(obj);
  keys.forEach(function (k) {
    if (typeof obj[k] === 'object') {
      flattenedValues[k] = obj[k].value;
    }
  });
  return flattenedValues;
};
/**
 * @param obj - object to trim
 * @returns {any} - object with trimmed values
 * @description trimValuesInObject function returns an object with trimmed values
 */
var trimValuesInObject = function trimValuesInObject(obj) {
  var trimmedValues = _extends({}, obj);
  var keys = Object.keys(obj);
  keys.forEach(function (k) {
    return obj[k] = typeof obj[k] == 'string' ? trimmedValues[k] = String(obj[k]).trim() : trimmedValues[k] = obj[k];
  });
  return trimmedValues;
};
var parseForm = function parseForm(form) {
  if (!(form != null && form.formatVersion)) {
    throw new Error('formatVersion is required');
  }
  switch (form.formatVersion) {
    case 1:
      return parseFormV1(form);
    case 2:
      return parseFormV2(form);
    default:
      throw new Error('The parsing function for this version of forms is not implemented');
  }
};

exports.buildYupSchema = buildYupSchema;
exports.createErrorObject = createErrorObject;
exports.formatYupValidationErrors = formatYupValidationErrors;
exports.functionFromString = functionFromString;
exports.getAllFieldNames = getAllFieldNames;
exports.getErrorMessages = getErrorMessages;
exports.getFieldError = getFieldError;
exports.getInitialValues = getInitialValues;
exports.getRuleValueFromSchema = getRuleValueFromSchema;
exports.isFormGroup = isFormGroup;
exports.makeCrossFieldValidation = makeCrossFieldValidation;
exports.parseForm = parseForm;
exports.validateValues = validateValues;
//# sourceMappingURL=index.js.map
