import { IFormV2 } from './models';
import { EnumType } from './modelsCommon';
import { IFormSettings, IFormParsed } from './modelsParsed';

export const parseFormV2 = <T extends EnumType>(form: IFormV2<T>): IFormParsed<T> => {
  const {
    submitButtonText,
    cancelButtonText,
    validationObject,
    crossFieldValidations,
    crossFieldConditions,
    formLayout,
    children,
  } = form;

  const allFieldNames = Object.keys(validationObject.properties) as T[];

  const formOptions = allFieldNames.reduce((acc, fieldName) => {
    const fieldLayout = formLayout[fieldName] || {
      md: 12,
      sm: 12,
      xs: 12,
    };

    acc[fieldName] = {
      crossFieldValidations: crossFieldValidations?.[fieldName],
      crossFieldConditions: crossFieldConditions?.[fieldName],
      fieldLayout,
    };

    return acc;
  }, {} as IFormSettings<T>);

  return {
    formatVersion: 'parsed',
    jsonSchema: validationObject,
    formSettings: formOptions,
    children,
    submitButtonText,
    cancelButtonText,
  };
};
